@@ -1,10 +1,7 @@
 
 use Linux::LVM;
-use Data::Dumper;
 
-%hash = get_pv_info("/dev/hdd1");
-
-print Dumper(\%hash);
+%hash = get_pv_info("/dev/hdb");
 
 foreach(sort keys %hash) {
     print "$_ = $hash{$_} \n";
